@@ -6,7 +6,7 @@ Once you understand this example you'll know the basics of OpenID
 and using the Python OpenID library. You can then move on to more
 robust examples, and integrating OpenID into your application.
 """
-__copyright__ = 'Copyright 2005-2007, Janrain, Inc.'
+__copyright__ = 'Copyright 2005-2008, Janrain, Inc.'
 
 from Cookie import SimpleCookie
 import cgi
@@ -68,8 +68,12 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
 
     session = None
 
-    def getConsumer(self):
-        return consumer.Consumer(self.getSession(), self.server.store)
+    def getConsumer(self, stateless=False):
+        if stateless:
+            store = None
+        else:
+            store = self.server.store
+        return consumer.Consumer(self.getSession(), store)
 
     def getSession(self):
         """Return the existing session or a new session"""
@@ -163,8 +167,9 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
         immediate = 'immediate' in self.query
         use_sreg = 'use_sreg' in self.query
         use_pape = 'use_pape' in self.query
+        use_stateless = 'use_stateless' in self.query
 
-        oidconsumer = self.getConsumer()
+        oidconsumer = self.getConsumer(stateless = use_stateless)
         try:
             request = oidconsumer.begin(openid_url)
         except consumer.DiscoveryFailure, exc:
@@ -199,12 +204,12 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
                     self.writeUserHeader()
                     self.end_headers()
                 else:
-                    form_html = request.formMarkup(
+                    form_html = request.htmlMarkup(
                         trust_root, return_to,
                         form_tag_attrs={'id':'openid_message'},
                         immediate=immediate)
 
-                    self.autoSubmit(form_html, 'openid_message')
+                    self.wfile.write(form_html)
 
     def requestRegistrationData(self, request):
         sreg_request = sreg.SRegRequest(
@@ -230,12 +235,14 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
         sreg_resp = None
         pape_resp = None
         css_class = 'error'
-        if info.status == consumer.FAILURE and info.identity_url:
+        display_identifier = info.getDisplayIdentifier()
+
+        if info.status == consumer.FAILURE and display_identifier:
             # In the case of failure, if info is non-None, it is the
             # URL that we were verifying. We include it in the error
             # message to help the user figure out what happened.
             fmt = "Verification of %s failed: %s"
-            message = fmt % (cgi.escape(info.identity_url),
+            message = fmt % (cgi.escape(display_identifier),
                              info.message)
         elif info.status == consumer.SUCCESS:
             # Success means that the transaction completed without
@@ -247,7 +254,7 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
             # was a real application, we would do our login,
             # comment posting, etc. here.
             fmt = "You have successfully verified %s as your identity."
-            message = fmt % (cgi.escape(info.identity_url),)
+            message = fmt % (cgi.escape(display_identifier),)
             sreg_resp = sreg.SRegResponse.fromSuccessResponse(info)
             pape_resp = pape.Response.fromSuccessResponse(info)
             if info.endpoint.canonicalID:
@@ -275,8 +282,8 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
             # information in a log.
             message = 'Verification failed.'
 
-        self.render(message, css_class, info.identity_url, sreg_data=sreg_resp,
-                    pape_data=pape_resp)
+        self.render(message, css_class, display_identifier,
+                    sreg_data=sreg_resp, pape_data=pape_resp)
 
     def doAffiliate(self):
         """Direct the user sign up with an affiliate OpenID provider."""
@@ -303,7 +310,7 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
             odd = ' class="odd"'
             for k, v in sreg_list:
                 field_name = sreg.data_fields.get(k, k)
-                value = cgi.escape(v)
+                value = cgi.escape(v.encode('UTF-8'))
                 self.wfile.write(
                     '<tr%s><td>%s</td><td>%s</td></tr>' % (odd, field_name, value))
                 if odd:
@@ -334,16 +341,6 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
         base = urlparse.urljoin(self.server.base_url, action)
         return appendArgs(base, query)
 
-    def autoSubmit(self, form, id):
-        """Send a page containing an auto-submitting form."""
-        response = """\
-<html><head><title>OpenID transaction in progress</title></head>
-<body onload='document.getElementById("%s").submit()'>
-%s
-</body></html>
-"""%(id, form)
-        self.wfile.write(response)
-
     def notFound(self):
         """Render a page with a 404 return code and a message."""
         fmt = 'The path <q>%s</q> was not understood by this server.'
@@ -374,7 +371,7 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
         """Render the page header"""
         self.setSessionCookie()
         self.wfile.write('''\
-Content-type: text/html
+Content-type: text/html; charset=UTF-8
 
 <html>
   <head><title>%s</title></head>
@@ -446,6 +443,7 @@ Content-type: text/html
         <input type="checkbox" name="immediate" id="immediate" /><label for="immediate">Use immediate mode</label>
         <input type="checkbox" name="use_sreg" id="use_sreg" /><label for="use_sreg">Request registration data</label>
         <input type="checkbox" name="use_pape" id="use_pape" /><label for="use_pape">Request phishing-resistent auth policy (PAPE)</label>
+        <input type="checkbox" name="use_stateless" id="use_stateless" /><label for="use_stateless">Use stateless mode</label>
       </form>
     </div>
   </body>
