@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-__copyright__ = 'Copyright 2005, Janrain, Inc.'
+__copyright__ = 'Copyright 2005-2008, Janrain, Inc.'
 
 from BaseHTTPServer import HTTPServer, BaseHTTPRequestHandler
 from urlparse import urlparse
@@ -337,7 +337,8 @@ class ServerHandler(BaseHTTPRequestHandler):
         id_url_base = self.server.base_url+'id/'
         # XXX: This may break if there are any synonyms for id_url_base,
         # such as referring to it by IP address or a CNAME.
-        assert request.identity.startswith(id_url_base), repr((request.identity, id_url_base))
+        assert (request.identity.startswith(id_url_base) or 
+                request.idSelect()), repr((request.identity, id_url_base))
         expected_user = request.identity[len(id_url_base):]
 
         if request.idSelect(): # We are being asked to select an ID
